@@ -467,13 +467,13 @@ def _format(val, valtype, floatfmt, missingval=""):
         return missingval
 
     if valtype in [int, _text_type]:
-        return "{0}".format(val)
+        return _text_type(val)
     elif valtype is _binary_type:
         return _text_type(val, "ascii")
     elif valtype is float:
         return format(float(val), floatfmt)
     else:
-        return "{0}".format(val)
+        return _text_type(val)
 
 
 def _align_header(header, alignment, width):
