@@ -104,8 +104,8 @@ class CommandTest(TestCase):
                     self.assertEqual(exception_code, 0)
                     output = output.getvalue()
                     self.assertTrue("CONNECT OK" in output)
-                    self.assertTrue("| http://127.0.0.1:44209     | crate     | TRUE      | OK" in output)
-                    self.assertTrue("| http://nonexistent.lol:123 | NULL      | FALSE     | Server not available" in output)
+                    self.assertTrue("| http://127.0.0.1:44209     | crate     | 0.41.4  | TRUE      | OK" in output)
+                    self.assertTrue("| http://nonexistent.lol:123 | NULL      | 0.0.0   | FALSE     | Server not available" in output)
         finally:
             try:
                 os.remove(tmphistory)
